<template>
  <CommonCard v-bind="rest" class="order-card-wrapper">
    <template #title-right v-if="showActionBtn">
      <slot name="title-right">
        <nut-button color="linear-gradient( 90deg, #569CFF 0%, #3A71FE 100%)">接单</nut-button>
      </slot>
    </template>
    <div class="order-card-content">
      <div class="order-card-content-info">
        <div class="order-card-content-info-item">{{ _hireNumber }}人</div>
        <div class="order-card-content-info-item-line"></div>
        <div class="order-card-content-info-item">{{ ageStart ?? 0 }}-{{ ageEnd ?? 0 }}周岁</div>
        <div class="order-card-content-info-item-line"></div>
        <div class="order-card-content-info-item">{{ `${provinceName}${cityName}` }}</div>
      </div>
      <div class="order-card-supplier-refund">
        <div class="order-card-supplier-refund-tag">合作</div>
        <div class="order-card-supplier-refund-text">
          {{ supplierRefund }}，{{ rebateModeText }}
        </div>
      </div>
    </div>
    <template #footer>
      <slot name="footer"></slot>
    </template>
  </CommonCard>
</template>

<script setup lang="ts">
import CommonCard from './CommonCard.vue';
import { OrderUtils } from '@12333/utils';
import { HireType } from '@12333/constants';

defineOptions({
  name: 'OrderCard',
});

type Props = {
  title?: string;
  src?: string;
  name?: string;
  jobTitle?: string;
  time?: string;
  hireType?: HireType;
  hireNumber?: number;
  hireEndNumber?: number;
  ageStart?: number;
  ageEnd?: number;
  provinceName?: string;
  cityName?: string;
  integratedSalary?: string;
  userId?: string;
  orderSupplierRefundInfo?: API.OrderSupplierRefundInfo[];
  showActionBtn?: boolean;
};

const {
  hireType,
  hireNumber,
  hireEndNumber,
  orderSupplierRefundInfo,
  showActionBtn = true,
  ...rest
} = defineProps<Props>();

const _hireNumber = computed(() => OrderUtils.getHireNumber(hireType, hireNumber, hireEndNumber));

const supplierRefund = computed(() => {
  if (orderSupplierRefundInfo) {
    return OrderUtils.getSupplierRefund(orderSupplierRefundInfo);
  }
  return '';
});

const rebateModeText = computed(() => {
  if (orderSupplierRefundInfo) {
    return OrderUtils.getRebateModeText(orderSupplierRefundInfo);
  }
  return '';
});
</script>

<style lang="scss">
@import '@/styles/common.scss';

.order-card-wrapper {
  .order-card-content {
    .order-card-content-info {
      font-weight: 400;
      font-size: 0;
      color: #9e9e9e;
      line-height: 34px;
      word-break: break-all;
      @include ellipsis;
      margin-bottom: 16px;

      .order-card-content-info-item {
        font-size: 24px;
        vertical-align: middle;
        display: inline-block;
      }

      .order-card-content-info-item-line {
        vertical-align: middle;
        display: inline-block;
        width: 2px;
        height: 20px;
        background-color: #979797;
        margin: 0 6px;
      }
    }

    .order-card-supplier-refund {
      display: flex;
      align-items: center;

      .order-card-supplier-refund-tag {
        height: 34px;
        background: #edf2ff;
        border-radius: 4px;
        padding: 0 8px;
        margin-right: 8px;
        font-weight: 400;
        font-size: 20px;
        color: boleGetCssVar('color', 'primary');
        line-height: 34px;
        flex-shrink: 0;
      }

      .order-card-supplier-refund-text {
        height: 34px;
        background: #f9faff;
        padding: 0 8px;
        font-weight: 400;
        font-size: 24px;
        color: boleGetCssVar('text-color', 'primary');
        line-height: 34px;
        @include ellipsis;
      }
    }
  }
}
</style>
